---
title: "Backups"
linkTitle: "Backups"
date: 2023-07-31T
weight: 4
description: >
    Backing up your services so that they are not lost
---

## Why backing up

When your service is broken but it worked yesterday you have two options:

  * Spend some time reading logs and debugging what went wrong. Meanwhile the service is unusable and maybe some data is irreversibly lost;
  * Restore the service to a working state and then debug at a more relaxed pace. Hopefully it was just a solar flare or a glitch in the Matrix.

This second, nerve-saving option is enabled by backing up regularly, and even better, automatically.

Having a backup simplifies the process of transferring a service between machines, ensuring minimal inconvenience.
This is useful if your datacenter is on fire, if your server provider gets bought out by another corporation, or when shareholders decide that it is finally time to make more profit.

This document covers the basic terms and usage of SelfPrivacy backup subsystem.

## What is a snapshot?

SelfPrivacy does not make backups of the whole machine.
Instead, it saves the states of each service.
The state of the files used by a service, taken at a certain time, is called a Snapshot.
In the interface, you can see that a snapshot has an ID, a service it backs up, and a date of creation.

## When backups occur?

A snapshot is created in 3 cases:

 * By user's manual command to back up a service;
 * Automatically at specified intervals if Automatic Backups are enabled;
 * As a precaution before an inplace restore of a service.

## How the data is stored?

The service's files are stored at the cloud of the user's choice.
We currently support Backblaze, with more to come.

All of the service data is encrypted with a local secret that the cloud never receives.
Under the hood, we use Restic to transfer encrypted data.

Cloud storage providers, such as Backblaze, have an option to prevent immediate deletion of data.

SelfPrivacy app uses this option so that in case when the server is hacked the data cannot be erased.

## Listing snapshots

There are 2 factors to keep in mind when looking at the list:

  * For the sake of performance, the list is cached. If some snapshots are missing which you think should be there, invalidate the cache so it reloads;
  * If you delete some snapshots, they will be removed from the list, but for some limited time they are still restorable with the help of the cloud.

## Restoring a snapshot

Restoring a snapshot involves stopping the service and reverting all files to their state at the snapshot's creation. This process can be accomplished in two distinct ways.

The safest one, the default one, is to download the snapshot in its entirety, verify that data is not damaged, and replace the service files with the files from the snapshot.
However, this method requires additional storage space for the snapshot.

A somewhat riskier way is to overwrite the service files directly, without intermediate storage. It requires less space, but if the transfer goes wrong, you end up with a broken service.
To help reduce the impact, a snapshot is taken just before restoring.

The app does check that we have enough space before attempting a restore.

## Forgetting a snapshot

Forgetting makes the snapshot inaccessible from the server, but deletion itself is reversible from cloud UI for some time (30 days for Backblaze by default).

## Automatic Backup

If you set up an automatic backup period, all of the services will be backed up according to the set period.

Note that backups are independent per service. If you have services A and B backed up automatically every day in the morning, and then you back up service B manually at noon, then service A's next backup will be in the morning as usual, but B's backups will occur at noons.

If it is disabled, automatic backups will not be performed.

## Restoring after someone has deleted all the snapshots

  * Go to your Backblaze/other cloud interface directly;
  * Rewind the bucket to its previous state before the deletion event;
  * Open SelfPrivacy app;
  * Update the snapshot list;
  * Restore from snapshots as usual.

## Troubleshooting backups

  * If you suspect that the list of snapshots is incorrect, try updating the snapshot list;
  * If an inplace restore has failed, make sure that your cloud is accessible and your contract is active. Then try to restore either a snapshot that you tried to restore or a pre-restore snapshot that was automatically generated;
  * If you do not have enough space on the disk for a safe restore, try restoring inplace.
